@@ -1,11 +1,11 @@
 package TeX::AutoTeX::Log;
 
 #
-# $Id: Log.pm,v 1.10.2.5 2011/01/27 18:42:28 thorstens Exp $
-# $Revision: 1.10.2.5 $
+# $Id: Log.pm,v 1.10.2.4 2011/01/03 04:06:00 thorstens Exp $
+# $Revision: 1.10.2.4 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/Log.pm,v $
 #
-# $Date: 2011/01/27 18:42:28 $
+# $Date: 2011/01/03 04:06:00 $
 # $Author: thorstens $
 #
 
@@ -14,7 +14,7 @@ use strict;
 use Carp;
 use TeX::AutoTeX::Exception;
 
-our ($VERSION) = '$Revision: 1.10.2.5 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.10.2.4 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 use IO::Handle; #for autoflush
 
@@ -105,7 +105,7 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::Log - log handling for TeX::AutoTeX
+TeX::AutoTeX::Log
 
 =head1 DESCRIPTION
 
@@ -127,7 +127,7 @@ Logging object for AutoTeX.
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
