@@ -1,11 +1,11 @@
 package TeX::AutoTeX::StampPDF;
 
 #
-# $Id: StampPDF.pm,v 1.9.2.7 2011/01/27 18:42:29 thorstens Exp $
-# $Revision: 1.9.2.7 $
+# $Id: StampPDF.pm,v 1.9.2.5 2011/01/22 04:52:14 thorstens Exp $
+# $Revision: 1.9.2.5 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/StampPDF.pm,v $
 #
-# $Date: 2011/01/27 18:42:29 $
+# $Date: 2011/01/22 04:52:14 $
 # $Author: thorstens $
 #
 
@@ -13,7 +13,7 @@ use strict;
 ### use warnings;
 use Carp qw(cluck carp);
 
-our ($VERSION) = '$Revision: 1.9.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.9.2.5 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 use parent qw(Exporter);
 our @EXPORT_OK = qw(stamp_pdf);
@@ -75,11 +75,11 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::StampPDF - watermark PDF files
+TeX::AutoTeX::StampPDF - printing the provided string on the left edge of the 1st page of a PDF
 
 =head1 VERSION
 
-This documentation refers to TeX::AutoTeX::StampPDF version 1.9.2.5
+This documentation refers to TeX::AutoTeX::StampPDF version 0.9
 
 =head1 SYNOPSIS
 
@@ -89,12 +89,9 @@ stamp_pdf($pdffile, $array_ref);
 
 =head1 DESCRIPTION
 
-This module modifies a given PDF file. It prints an arbitrary text string
-(within certain length limits) onto the left edge of the 1st page of a well
-formed PDF file.
+This module modifies a given PDF file. It prints an arbitrary text string (within certain length limits) onto the left edge of the 1st page of any well formed PDF file.
 
-This is intended to be used to put the arXiv stamp onto PDF-only and pdflatex
-submissions, but any type of "watermark" text string is possible.
+This is intended to be used to put the arXiv stamp onto PDF-only submissions and pdflatex submissions, but any type of "watermark" text string is possible.
 
 Non adjustable settings are:
 
@@ -132,9 +129,6 @@ none
 
 =head1 BUGS AND LIMITATIONS
 
-The placement of the stamp is tuned to US letter size paper and dimensions
-are hard-coded. This is easily adaptable to other paper sizes if necessary.
-
 Please report bugs to L<www-admin|http://arxiv.org/help/contact>
 
 =head1 AUTHOR
